@@ -1,7 +1,7 @@
 # maxCPU
-# Version 0.1.3 English version
+# Version 0.1.5 English version
 # Home Desktop Widget for fast change of CPU's clock
-# by Marco (m750 at www.maemomeego.net
+# by Marco (m750 at www.maemomeego.net)
 
 import hildondesktop
 import os
@@ -182,6 +182,7 @@ class maxCPU(hildondesktop.HomePluginItem):
 
         # dichiarazione box
         box1 = gtk.HBox()
+        box1.set_border_width(2)
 
         # aggiunta box e resto
         self.add(box1)
@@ -204,7 +205,7 @@ class maxCPU(hildondesktop.HomePluginItem):
         # dialog crea una finestra in basso con dei messaggi
         dialog = gtk.Dialog()
         dialog.set_title('maxCPU')
-        dialog.vbox.add(gtk.Label('Version 0.1.3 EN (2010-12-21)'))
+        dialog.vbox.add(gtk.Label('Version 0.1.5 EN (2010-12-21)'))
         dialog.vbox.add(gtk.Label('Fast change of CPU clock'))
         dialog.vbox.add(gtk.Label('250 Mhz<= Fmin <= newClock <= 1150 Mhz'))
         dialog.vbox.add(gtk.Label('Changes do not remain after reboot'))
